mgmtsystem - A simple virtualization client
===========================================

[![Coverage Status](https://coveralls.io/repos/RedHatQE/mgmtsystem/badge.svg?branch=master&service=github)](https://coveralls.io/github/RedHatQE/mgmtsystem?branch=master)
[![Build Status](https://travis-ci.org/RedHatQE/mgmtsystem.svg)](https://travis-ci.org/RedHatQE/mgmtsystem)
[![Code Health](https://landscape.io/github/RedHatQE/mgmtsystem/master/landscape.svg?style=flat)](https://landscape.io/github/RedHatQE/mgmtsystem/master)

